Component

Trait Component 

pub trait Component:
    Send
    + Sync
    + 'static { }
Types that can be components, implemented automatically for all Send + Sync + 'static types

This is just a convenient shorthand for Send + Sync + 'static, and never needs to be implemented manually.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Send + Sync + 'static> Component for T